Data

Struct Data 

pub struct Data { /* private fields */ }
Column-major table returned from CCDB fetch operations.

Implementations

Source

impl Data

pub fn from_vault( vault: &str, layout: Arc<ColumnLayout>, n_rows: usize, ) -> CCDBResult<Self>

Builds a Data table from a raw vault string and column metadata.

Errors

This method will return an error if the parsed number of columns does not equal the expected number from the database or if any of the column contents cannot be parsed into their respective data types.

pub fn n_rows(&self) -> usize

Number of rows in the dataset.

pub fn n_columns(&self) -> usize

Number of columns in the dataset.

pub fn column_names(&self) -> &[String]

Column names in positional order.

pub fn column_types(&self) -> &[ColumnType]

Column types in positional order.

pub fn column(&self, idx: usize) -> Option<&Column>

Returns a borrowed column by positional index.

pub fn named_column(&self, name: &str) -> Option<&Column>

Returns a borrowed column by name.

pub fn column_clone(&self, idx: usize) -> Option<Column>

Returns a cloned column by positional index.

pub fn named_column_clone(&self, name: &str) -> Option<Column>

Returns a cloned column by name.

pub fn value(&self, column: usize, row: usize) -> Option<Value<'_>>

Returns a single cell value by column and row index.

pub fn named_int(&self, name: &str, row: usize) -> Option<i32>

Returns a named cell as i32 if present and typed accordingly.

pub fn named_uint(&self, name: &str, row: usize) -> Option<u32>

Returns a named cell as u32 if present and typed accordingly.

pub fn named_long(&self, name: &str, row: usize) -> Option<i64>

Returns a named cell as i64 if present and typed accordingly.

pub fn named_ulong(&self, name: &str, row: usize) -> Option<u64>

Returns a named cell as u64 if present and typed accordingly.

pub fn named_double(&self, name: &str, row: usize) -> Option<f64>

Returns a named cell as f64 if present and typed accordingly.

pub fn named_string(&self, name: &str, row: usize) -> Option<&str>

Returns a named cell as &str if present and typed accordingly.

pub fn named_bool(&self, name: &str, row: usize) -> Option<bool>

Returns a named cell as bool if present and typed accordingly.

pub fn int(&self, column: usize, row: usize) -> Option<i32>

Returns a positional cell as i32 if present and typed accordingly.

pub fn uint(&self, column: usize, row: usize) -> Option<u32>

Returns a positional cell as u32 if present and typed accordingly.

pub fn long(&self, column: usize, row: usize) -> Option<i64>

Returns a positional cell as i64 if present and typed accordingly.

pub fn ulong(&self, column: usize, row: usize) -> Option<u64>

Returns a positional cell as u64 if present and typed accordingly.

pub fn double(&self, column: usize, row: usize) -> Option<f64>

Returns a positional cell as f64 if present and typed accordingly.

pub fn string(&self, column: usize, row: usize) -> Option<&str>

Returns a positional cell as &str if present and typed accordingly.

pub fn bool(&self, column: usize, row: usize) -> Option<bool>

Returns a positional cell as bool if present and typed accordingly.

pub fn row(&self, row: usize) -> CCDBResult<RowView<'_>>

Returns a borrowed view of a single row, or an error if out of bounds.

Errors

This method will return an error if row is out of bounds.

pub fn iter_rows(&self) -> impl Iterator<Item = RowView<'_>>

Iterates over all rows in the dataset.

pub fn iter_columns( &self, ) -> impl Iterator<Item = (&String, &ColumnType, &Column)>

Iterates over (name, type, column) tuples for each column.

pub fn contains(&self, name: &str) -> bool

True if a column with the given name exists.