TypeTableHandle

Struct TypeTableHandle 

pub struct TypeTableHandle { /* private fields */ }
Handle to a CCDB table, enabling metadata inspection and data fetches.

Implementations

Source

impl TypeTableHandle

pub fn meta(&self) -> &TypeTableMeta

Returns the table metadata as loaded from CCDB.

pub fn name(&self) -> &str

Returns the table name (without parent path components).

pub fn id(&self) -> Id

Returns the unique numeric identifier for this table.

pub fn full_path(&self) -> String

Returns the absolute path of this table, including directory prefix.

pub fn columns(&self) -> CCDBResult<Vec<ColumnMeta>>

Loads column metadata for this table.

Errors

This method will fail if the underlying SQL query fails or any part of the columns table fails to parse.

pub fn fetch(&self, ctx: &CCDBContext) -> CCDBResult<BTreeMap<RunNumber, Data>>

Fetches data for this table using the provided query context.

Errors

Returns an error if resolving assignments fails, if any SQL queries fail, or if vault data cannot be decoded for the requested runs.