CCDBError

Enum CCDBError 

pub enum CCDBError {
Show 14 variants SqliteError(Error), DirectoryNotFoundError(String), TableNotFoundError(String), PathResolutionError(Error), InvalidPathError(String), VariationNotFoundError(String), NotAbsolutePath(String), IllegalCharacter(String), InvalidRunNumberError(String), ColumnCountMismatch { expected: usize, found: usize, }, ParseError { column: usize, row: usize, column_type: ColumnType, text: String, }, RowOutOfBounds { requested: usize, n_rows: usize, }, GlueXCoreError(GlueXCoreError), MissingConnectionEnv(String),
}
Errors that can occur while interacting with CCDB metadata or payloads.

Variants



SqliteError(Error)

Wrapper around rusqlite::Error.



DirectoryNotFoundError(String)

Requested directory path could not be resolved.



TableNotFoundError(String)

Requested table path could not be resolved.



PathResolutionError(Error)

Failed to resolve or canonicalize a filesystem path.



InvalidPathError(String)

Path was malformed or missing a required component.



VariationNotFoundError(String)

Variation name does not exist in the database.



NotAbsolutePath(String)

Path did not begin with a forward slash.



IllegalCharacter(String)

Path contained a character outside the allowed set.



InvalidRunNumberError(String)

Run number was not a valid integer.



ColumnCountMismatch

Failed to parse data because the number of cells was not divisible by the number of columns.

Fields

expected: usize

The total expected number of cells.

found: usize

The number of cells found while parsing.



ParseError

Failed to parse a cell to the given type.

Fields

column: usize

The column index of the cell.

row: usize

The row index of the cell.

column_type: ColumnType

The expected column type for the cell.

text: String

The unparsed contents of the cell.



RowOutOfBounds

Failed to retrieve a row due to an out-of-bounds index.

Fields

requested: usize

The requested index.

n_rows: usize

The available number of rows.



GlueXCoreError(GlueXCoreError)

Timestamp string failed to parse.



MissingConnectionEnv(String)

Required environment variable is not set.