pub struct AssignmentMeta { /* private fields */ }Expand description
Metadata describing an assignment of a constant set to a run/event range.
Implementations
Sourceimpl AssignmentMeta
impl AssignmentMeta
Sourcepub fn variation_id(&self) -> Id
pub fn variation_id(&self) -> Id
Identifier of the variation referenced by the assignment.
Sourcepub fn run_range_id(&self) -> Id
pub fn run_range_id(&self) -> Id
Identifier of the associated run range.
Sourcepub fn event_range_id(&self) -> Id
pub fn event_range_id(&self) -> Id
Identifier of the associated event range.
Identifier of the user who created the assignment.
Sourcepub fn constant_set_id(&self) -> Id
pub fn constant_set_id(&self) -> Id
Identifier of the constant set referenced by the assignment.