pub struct AssignmentMetaLite { /* private fields */ }Expand description
Lightweight assignment row containing only identity and creation info.
Implementations
Sourceimpl AssignmentMetaLite
impl AssignmentMetaLite
Sourcepub fn constant_set_id(&self) -> Id
pub fn constant_set_id(&self) -> Id
Identifier of the constant set referenced by the assignment.