pub struct ConstantSetMeta { /* private fields */ }Expand description
Metadata describing a stored set of constants for a type table.
Implementations
Sourceimpl ConstantSetMeta
impl ConstantSetMeta
Sourcepub fn constant_type_id(&self) -> Id
pub fn constant_type_id(&self) -> Id
Identifier of the type table the set belongs to.