pub struct DirectoryMeta { /* private fields */ }Expand description
Metadata describing a directory entry that groups constant types.
Implementations
Sourceimpl DirectoryMeta
impl DirectoryMeta
Identifier of the user who created the directory.
Sourcepub fn is_deprecated(&self) -> bool
pub fn is_deprecated(&self) -> bool
True when the directory has been marked as deprecated.
Sourcepub fn deprecated_by_user_id(&self) -> Id
pub fn deprecated_by_user_id(&self) -> Id
Identifier of the user who deprecated the directory.
Sourcepub fn locked_by_user_id(&self) -> Id
pub fn locked_by_user_id(&self) -> Id
Identifier of the user who locked the directory.