pub struct PyCCDB { /* private fields */ }Expand description
Entry point for interacting with CCDB from Python.
Parameters
path : str, optional
Filesystem path to an existing CCDB SQLite database file. Defaults to
the CCDB_CONNECTION environment variable.
Implementations
Sourceimpl PyCCDB
impl PyCCDB
Sourcepub fn new(path: Option<String>) -> PyResult<Self>
pub fn new(path: Option<String>) -> PyResult<Self>
init(self, path)
Parameters
path : str, optional
Filesystem path to an existing CCDB SQLite database file. Defaults
to CCDB_CONNECTION.
Sourcepub fn dir(&self, path: &str) -> PyResult<PyDirectoryHandle>
pub fn dir(&self, path: &str) -> PyResult<PyDirectoryHandle>
Sourcepub fn table(&self, path: &str) -> PyResult<PyTypeTableHandle>
pub fn table(&self, path: &str) -> PyResult<PyTypeTableHandle>
Sourcepub fn fetch(
&self,
path: &str,
runs: Option<Vec<RunNumber>>,
variation: Option<String>,
timestamp: Option<Bound<'_, PyAny>>,
) -> PyResult<BTreeMap<RunNumber, PyData>>
pub fn fetch( &self, path: &str, runs: Option<Vec<RunNumber>>, variation: Option<String>, timestamp: Option<Bound<'_, PyAny>>, ) -> PyResult<BTreeMap<RunNumber, PyData>>
fetch(self, path, *, runs=None, variation=None, timestamp=None)
Parameters
path : str Absolute or relative table path. runs : list[int] | None, optional Run numbers to query; defaults to run 0 when omitted. variation : str | None, optional Variation branch to resolve (default “default”). timestamp : datetime | str | None, optional Timestamp used to select historical assignments.
Returns
dict[int, Data] Mapping of run number to fetched dataset.
Sourcepub fn fetch_run_period(
&self,
path: &str,
run_period: &str,
rest_version: Option<Bound<'_, PyAny>>,
variation: Option<String>,
timestamp: Option<Bound<'_, PyAny>>,
) -> PyResult<BTreeMap<RunNumber, PyData>>
pub fn fetch_run_period( &self, path: &str, run_period: &str, rest_version: Option<Bound<'_, PyAny>>, variation: Option<String>, timestamp: Option<Bound<'_, PyAny>>, ) -> PyResult<BTreeMap<RunNumber, PyData>>
fetch_run_period(self, path, *, run_period, rest_version=None, variation=None, timestamp=None)
Parameters
path : str Absolute or relative table path. run_period : str The short string of the corresponding GlueX run period (e.g. “S17”, “F18”) rest_version : int | datetime | None, optional The REST version or explicit timestamp to use when resolving a time stamp. variation : str | None, optional Variation branch to resolve (default “default”). timestamp : datetime | str | None, optional Timestamp used to select historical assignments. This will override timestamp from the REST version if provided
Returns
dict[int, Data] Mapping of run number to fetched dataset.
Sourcepub fn root(&self) -> PyResult<PyDirectoryHandle>
pub fn root(&self) -> PyResult<PyDirectoryHandle>
Sourcepub fn connection_path(&self) -> &str
pub fn connection_path(&self) -> &str
str: Filesystem path that was used to open the database.