pub struct PyRowView { /* private fields */ }Expand description
Lightweight view of a single row in a CCDB result set.
Attributes
n_columns : int Number of columns available in the row. column_types : listColumnType Storage type for each column in the row.
Implementations
Sourceimpl PyRowView
impl PyRowView
Sourcepub fn n_columns(&self, _py: Python<'_>) -> usize
pub fn n_columns(&self, _py: Python<'_>) -> usize
int: Number of columns available in this row.
Sourcepub fn column_types(&self, _py: Python<'_>) -> Vec<PyColumnType>
pub fn column_types(&self, _py: Python<'_>) -> Vec<PyColumnType>
listColumnType: Column types for this row in positional order.