pub struct TypeTableHandle { /* private fields */ }Expand description
Handle to a CCDB table, enabling metadata inspection and data fetches.
Implementations
Sourceimpl TypeTableHandle
impl TypeTableHandle
Sourcepub fn meta(&self) -> &TypeTableMeta
pub fn meta(&self) -> &TypeTableMeta
Returns the table metadata as loaded from CCDB.
Sourcepub fn full_path(&self) -> String
pub fn full_path(&self) -> String
Returns the absolute path of this table, including directory prefix.
Sourcepub fn columns(&self) -> CCDBResult<Vec<ColumnMeta>>
pub fn columns(&self) -> CCDBResult<Vec<ColumnMeta>>
Loads column metadata for this table.
Errors
This method will fail if the underlying SQL query fails or any part of the columns table
fails to parse.
Sourcepub fn fetch(&self, ctx: &CCDBContext) -> CCDBResult<BTreeMap<RunNumber, Data>>
pub fn fetch(&self, ctx: &CCDBContext) -> CCDBResult<BTreeMap<RunNumber, Data>>
Fetches data for this table using the provided query context.
Errors
Returns an error if resolving assignments fails, if any SQL queries fail, or if vault data cannot be decoded for the requested runs.