pub struct VariationMeta { /* private fields */ }Expand description
Metadata describing a variation that partitions assignments.
Implementations
Sourceimpl VariationMeta
impl VariationMeta
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Optional descriptive text for the variation.
Identifier of the user who created the variation.
Sourcepub fn locked_by_user_id(&self) -> Id
pub fn locked_by_user_id(&self) -> Id
Identifier of the user who locked the variation.
Sourcepub fn go_back_behavior(&self) -> i64
pub fn go_back_behavior(&self) -> i64
Behavior flag defining how lookups walk parent variations.
Sourcepub fn is_deprecated(&self) -> bool
pub fn is_deprecated(&self) -> bool
True when the variation is deprecated.
Sourcepub fn deprecated_by_user_id(&self) -> Id
pub fn deprecated_by_user_id(&self) -> Id
Identifier of the user who deprecated the variation.
Sourcepub fn created(&self) -> CCDBResult<DateTime<Utc>>
pub fn created(&self) -> CCDBResult<DateTime<Utc>>
Timestamp describing when the variation was created.
Errors
Returns an error if the stored creation timestamp cannot be parsed as a UTC datetime.
Sourcepub fn modified(&self) -> CCDBResult<DateTime<Utc>>
pub fn modified(&self) -> CCDBResult<DateTime<Utc>>
Timestamp describing when the variation metadata was updated.
Errors
Returns an error if the stored modification timestamp cannot be parsed as a UTC datetime.
Sourcepub fn lock_time(&self) -> CCDBResult<DateTime<Utc>>
pub fn lock_time(&self) -> CCDBResult<DateTime<Utc>>
Timestamp describing when the variation was locked.
Errors
Returns an error if the stored lock timestamp cannot be parsed as a UTC datetime.
Sourcepub fn go_back_time(&self) -> CCDBResult<DateTime<Utc>>
pub fn go_back_time(&self) -> CCDBResult<DateTime<Utc>>
Timestamp describing when the go-back window expires.
Errors
Returns an error if the stored go-back timestamp cannot be parsed as a UTC datetime.